%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Indirect energy requirements of Beijing household consumption
%
% Programmer: Anders Arvesen
% Date started: 5 mars 2008
%
% Units: Expenditures:  yuan/cap
%        Energy:        GJ/cap
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all; clc

n_IO = 122;     % Number of IO industry sectors
n_SCE_urb = 77; % Number of Beijing survey of consumer expenditure (SCE) categories, urban
n_SCE_rur = 23; % Number of SCE categories, rural
n_inc_urb = 6;  % Number of socioeconomic groups, urban (includes one "artificial" group, the very-high income group)
n_inc_rur = 5;  % Number of socioeconomic groups, rural

filename_w = 'Results.xls'; % Write results to

% Specify category numbers for electricity (household electricity use is
% included in the results but then removed)
cat_no_el_urb = 69; % Urban
cat_no_el_rur = 6;  % Rural
cat_no_el_IO = 85;  % Number for the category 'Electricity and steam production and supply' in the IO table

% Load input-output data (Source: Glen Peters)
load('China_2002_data_mod');

% Do calculations for energy only. Remove data for CO2, SO2, NOx.
F02_IO = F02_122(1,:);

% Delete unnecessary variables from Glen Peters' data set
clear F02_122 y02* x02 Z02 P02_Energy I G02_122 G02 F02 x02_total A02

% Load expenditure survey data for five income groups
y_SCE_urb = Convert_NaN(xlsread('Expenditures.xls', 'Beijing_urban', 'C8:I84'));    % Urban
y_SCE_rur = Convert_NaN(xlsread('Expenditures.xls', 'Beijing_rural', 'C52:H74'));   % Rural

% Use consumer price index (CPI) to convert y to 2002 prices
CPI_2005=647.8/630.6; % 1978=100; Source: Table 6.2 Beijing Statistical Yearbook

y_SCE_urb = y_SCE_urb./CPI_2005;
y_SCE_rur = y_SCE_rur./CPI_2005;

% Load concordances
P_SCEtoIO_urb = Convert_NaN(xlsread('Concordances.xls', 'Urban_SCE2005_to_IO2002', 'E3:DV79')); % Urban
P_SCEtoIO_rur = Convert_NaN(xlsread('Concordances.xls', 'Rural_SCE2005_to_IO2002', 'C3:DT25')); % Rural

% Map expenditures to IO industry sectors
y_IO_urb = P_SCEtoIO_urb'*y_SCE_urb;
y_IO_rur = P_SCEtoIO_rur'*y_SCE_rur;

% Specify section to write data to
section_w_urb = 'C10:I86';
section_w_rur = 'M10:R32';

% Perform calculations, urban
for k = 1:n_inc_urb+1
    
    % 'Invert' concordances
    P_IOtoSCE_temp = invert_conc(n_IO, n_SCE_urb, y_SCE_urb(:,k), P_SCEtoIO_urb, y_IO_urb(:,k));
        
    % Calculate
    e_SCE_urb(:,k) = calculate(section_w_urb, F02_IO, y_IO_urb(:,k), n_inc_urb, L02, P_SCEtoIO_urb, P_IOtoSCE_temp, cat_no_el_urb, cat_no_el_IO);
        
    % Clear
    clear P_IOtoSCE_temp
end

% Perform calculations ,rural
for k = 1:n_inc_rur+1
       
    % 'Invert' concordances
    P_IOtoSCE_temp = invert_conc(n_IO, n_SCE_rur, y_SCE_rur(:,k), P_SCEtoIO_rur, y_IO_rur(:,k));
        
    % Calculate
    e_SCE_rur(:,k) = calculate(section_w_rur, F02_IO, y_IO_rur(:,k), n_inc_rur, L02, P_SCEtoIO_rur, P_IOtoSCE_temp, cat_no_el_rur, cat_no_el_IO);
        
    % Clear
    clear P_IOtoSCE_temp
        
end

clear k

% Write results to excel file
xlswrite(filename_w, e_SCE_urb, 'Energy', section_w_urb)
xlswrite(filename_w, e_SCE_rur, 'Energy', section_w_rur)

