%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script concerns itself with the construction of the 'very high'
% income group. The script loads aggregated expenditure data for the
% very-high income group (this data is already established in excel),
% disaggregates the data, and writes the disaggregated data to excel file.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all; clc

% Loads aggregated data for the very high income group
y_vh_aggr = xlsread('Expenditures.xls','Projections_urb','H231:H241');

% The assumption is made that the distribution of expenditures within one
% aggregated category is the same for the very high income households as
% for the high income households. For example, grain constitutes 4.8% of
% the high income households expenditures on the aggregated category 
% 'food'. Therefore, the assumption is made that grain constitutes 4.8% of
% the very-high income households expenditures food. Thus, the share of 
% expenditure on grain to total expenditures on food is the same for the 
% high and very-high income households, but the total (absolute) 
% expenditures on food is different

% Loads disaggragated data for the high income group.
y_h_disaggr = xlsread('Expenditures.xls','Beijing_urban','H8:H84');

% Aggregated categories
food = 1:25; clothing = 26:32; household_articles = 33:41; health = 42:47;
transport = 48:51; communication = 52:53; culture_and_recr = 54:55;
education = 56:63; water_el_fuel = 68:74; housing1 = 64:67; housing2 = 75; % Note: 75 also belongs to 'housing'
misc = 76:77;

% Calculates percentage shares of disaggragetad categories to the
% aggreageted categories of the high income group (distribution of 
% expenditures within one aggregated category).
y_high_inc_perc(food) = y_h_disaggr(food)/sum(y_h_disaggr(food));
y_high_inc_perc(clothing) = y_h_disaggr(clothing)/sum(y_h_disaggr(clothing));
y_high_inc_perc(household_articles) = y_h_disaggr(household_articles)/sum(y_h_disaggr(household_articles));
y_high_inc_perc(health) = y_h_disaggr(health)/sum(y_h_disaggr(health));
y_high_inc_perc(transport) = y_h_disaggr(transport)/sum(y_h_disaggr(transport));
y_high_inc_perc(communication) = y_h_disaggr(communication)/sum(y_h_disaggr(communication));
y_high_inc_perc(culture_and_recr) = y_h_disaggr(culture_and_recr)/sum(y_h_disaggr(culture_and_recr));
y_high_inc_perc(education) = y_h_disaggr(education)/sum(y_h_disaggr(education));
y_high_inc_perc(water_el_fuel) = y_h_disaggr(water_el_fuel)/sum(y_h_disaggr(water_el_fuel));
y_high_inc_perc(housing1) = y_h_disaggr(housing1)/(sum(y_h_disaggr(housing1))+y_h_disaggr(housing2));
y_high_inc_perc(housing2) = y_h_disaggr(housing2)/(sum(y_h_disaggr(housing1))+y_h_disaggr(housing2));
y_high_inc_perc(misc) = y_h_disaggr(misc)/sum(y_h_disaggr(misc));

y_very_high_disaggr = zeros(length(y_h_disaggr),1);

% Calculates disaggregated of the very-high income group, on the basis of
% aggregated expenditures of the very-high income group and distribution of
% expenditures within one category for the high income group.
y_very_high_disaggr(food) = y_vh_aggr(1)*y_high_inc_perc(food);
y_very_high_disaggr(clothing) = y_vh_aggr(2)*y_high_inc_perc(clothing);
y_very_high_disaggr(household_articles) = y_vh_aggr(3)*y_high_inc_perc(household_articles);
y_very_high_disaggr(health) = y_vh_aggr(4)*y_high_inc_perc(health);
y_very_high_disaggr(transport) = y_vh_aggr(5)*y_high_inc_perc(transport);
y_very_high_disaggr(communication) = y_vh_aggr(6)*y_high_inc_perc(communication);
y_very_high_disaggr(culture_and_recr) = y_vh_aggr(7)*y_high_inc_perc(culture_and_recr);
y_very_high_disaggr(education) = y_vh_aggr(8)*y_high_inc_perc(education);
y_very_high_disaggr(water_el_fuel) = y_vh_aggr(9)*y_high_inc_perc(water_el_fuel);
y_very_high_disaggr(housing1) = y_vh_aggr(10)*y_high_inc_perc(housing1);
y_very_high_disaggr(housing2) = y_vh_aggr(10)*y_high_inc_perc(housing2);
y_very_high_disaggr(misc) = y_vh_aggr(11)*y_high_inc_perc(misc);

xlswrite('Expenditures.xls',y_very_high_disaggr,'Beijing_urban','I8:I84');